@@ -34,6 +34,7 @@ from quickbuild.exceptions import (
     QBNotFoundError,
     QBProcessingError,
     QBServerError,
+    QBUnauthorizedError,
 )
 from quickbuild.helpers import ContentType
 
@@ -44,10 +45,10 @@ Response = namedtuple('Response', ['status', 'headers', 'body'])
 
 class QuickBuild:
     """
-    NB: somehow using -H "Accept: application/json,application/xml,*/*" leads
-    to server error.
+    NB: somehow using -H Accept: application/json,application/xml,*/* leads to
+    server error.
     """
-    def __init__(self, content_type: Optional[ContentType]):
+    def __init__(self, content_type: Optional[ContentType]) -> None:
         self._content_type = content_type
 
         self.agents = Agents(self)
@@ -94,6 +95,9 @@ class QuickBuild:
         if response.status == HTTPStatus.NOT_FOUND:
             raise QBNotFoundError(response.body)
 
+        if response.status == HTTPStatus.UNAUTHORIZED:
+            raise QBUnauthorizedError(response.body)
+
         if response.status == HTTPStatus.FORBIDDEN:
             raise QBForbiddenError(response.body)
 
