@@ -1,5 +1,6 @@
 from .agents import Agents
 from .audits import Audits
+from .authorizations import Authorizations
 from .builds import Builds
 from .changes import Changes
 from .configurations import Configurations
@@ -10,6 +11,7 @@ from .issues import Issues
 from .measurements import Measurements
 from .memberships import Memberships
 from .nodes import Nodes
+from .profiles import Profiles
 from .reports import Reports
 from .requests import Requests
 from .resources import Resources
@@ -21,6 +23,7 @@ from .users import Users
 __all__ = (
     'Agents',
     'Audits',
+    'Authorizations',
     'Builds',
     'Changes',
     'Configurations',
@@ -31,6 +34,7 @@ __all__ = (
     'Measurements',
     'Memberships',
     'Nodes',
+    'Profiles',
     'Reports',
     'Requests',
     'Resources',
