@@ -5,7 +5,7 @@ from quickbuild.helpers import response2py
 
 class Resources:
 
-    def __init__(self, quickbuild):
+    def __init__(self, quickbuild) -> None:
         self.quickbuild = quickbuild
 
     def get(self) -> List[dict]:
