@@ -7,7 +7,7 @@ from quickbuild.helpers import ContentType, response2py
 
 class Users:
 
-    def __init__(self, quickbuild):
+    def __init__(self, quickbuild) -> None:
         self.quickbuild = quickbuild
 
         self.shares = UserShares(quickbuild)
@@ -42,7 +42,7 @@ class Users:
                 instance is used.
 
         Returns:
-            dict: information about user.
+            Union[dict, str]: information about user.
         """
         return self.quickbuild._request(
             'GET',
@@ -56,7 +56,8 @@ class Users:
         Get display name for specified user.
 
         Args:
-            user_id (int): user identifier.
+            user_id (int):
+                User identifier.
 
         Returns:
             str: user name.
@@ -71,7 +72,8 @@ class Users:
         Get user id by name.
 
         Args:
-            name (str): user name.
+            name (str):
+                User name.
 
         Returns:
             int: user identifier.
@@ -90,7 +92,8 @@ class Users:
         parts of the XML and post back to above url.
 
         Args:
-            configuration (str): XML document.
+            configuration (str):
+                XML document.
 
         Returns:
             int: user id being updated.
@@ -127,7 +130,8 @@ class Users:
         Delete user by user id.
 
         Args:
-            user_id (int): user identifier.
+            user_id (int):
+                User identifier.
 
         Returns:
             None
